@@ -1,5 +1,8 @@
-from notecoin.okex.websocket.utils import (check, get_local_timestamp, partial,
-                                           update_asks, update_bids)
+import logging
+
+from notecoin.database.base import db
+from notecoin.okex.websocket.dataset import OkexSocketPublicTickers
+from notecoin.okex.websocket.utils import get_local_timestamp
 
 
 class BaseHandle:
@@ -24,6 +27,9 @@ class PublicBooks(BaseHandle):
         super(PublicBooks, self).__init__(channels=['books'], *args, **kwargs)
 
     def handle(self, data) -> bool:
+        from notecoin.okex.websocket.utils import (check, partial, update_asks,
+                                                   update_bids)
+
         l = []
         if data['action'] == 'snapshot':
             for m in l:
@@ -69,3 +75,19 @@ class PublicBooks(BaseHandle):
                         print("校验结果为:False，正在重新订阅……")
                         return False
         return True
+
+
+class PublicTickers(BaseHandle):
+    def __init__(self, *args, **kwargs):
+        db.create_all()
+        super(PublicTickers, self).__init__(channels=['tickers'], *args, **kwargs)
+
+    def handle(self, data) -> bool:
+        try:
+            for arg in data['data']:
+                db.session.merge(OkexSocketPublicTickers(**arg))
+                db.session.commit()
+        except Exception as e:
+            logging.error(f"error:{e}")
+            return False
+        return True
